<?php
/**
 * Tungsten functions and definitions
 *
 * @package Tungsten
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 640; /* pixels */
}

if ( ! function_exists( 'tungsten_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function tungsten_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Tungsten, use a find and replace
	 * to change 'tungsten' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'tungsten', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'tungsten' ),
	) );

	// Setup the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'tungsten_custom_background_args', array(
		'default-color' => '131313',
		'default-image' => '',
	) ) );
	set_post_thumbnail_size( 200, 200, true );
	add_theme_support( 'post-thumbnails' );
}
endif; // tungsten_setup
add_action( 'after_setup_theme', 'tungsten_setup' );

/**
 * Register widgetized area and update sidebar with default widgets.
 */
function tungsten_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'tungsten' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
}
add_action( 'widgets_init', 'tungsten_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function tungsten_scripts() {
	wp_enqueue_style( 'tungsten-style', get_stylesheet_uri() );
	wp_enqueue_style( 'open-sans-font', 'http://fonts.googleapis.com/css?family=Open+Sans:400,300,700' );
	wp_enqueue_style(  'font-awesome','//netdna.bootstrapcdn.com/font-awesome/4.0.3/css/font-awesome.css');
	wp_enqueue_style( 'crimson-ie-only', get_template_directory_uri().'/css/ie.css' );
	global $wp_styles;
	$wp_styles->add_data( 'crimson-ie-only', 'conditional', 'lt IE 9' );
	wp_enqueue_script( 'tungsten-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );
	wp_enqueue_script( 'tungsten-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

	if(is_front_page()){
		wp_enqueue_script( 'responsive-slides', get_template_directory_uri() . '/js/responsiveslides.min.js', array('jquery'), '1.0', true );
	}

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'tungsten_scripts' );

/**
 * Implement the Custom Header feature.
 */
//require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Load Options Panel
 */
require get_template_directory() . '/inc/options-panel.php';